Class: Geet::Github::Collaborator
- Inherits:
-
Object
- Object
- Geet::Github::Collaborator
- Defined in:
- lib/geet/github/collaborator.rb
Class Method Summary collapse
-
.list(api_interface) ⇒ Object
Returns a flat list of names in string form.
Class Method Details
.list(api_interface) ⇒ Object
Returns a flat list of names in string form.
9 10 11 12 13 14 |
# File 'lib/geet/github/collaborator.rb', line 9 def self.list(api_interface) api_path = 'collaborators' response = api_interface.send_request(api_path, multipage: true) response.map { |user_entry| user_entry.fetch('login') } end |