Class: Geet::Github::Label
- Inherits:
-
Object
- Object
- Geet::Github::Label
- Defined in:
- lib/geet/github/label.rb
Class Method Summary collapse
-
.list(api_interface) ⇒ Object
Returns a flat list of names in string form.
Class Method Details
.list(api_interface) ⇒ Object
Returns a flat list of names in string form.
9 10 11 12 13 14 |
# File 'lib/geet/github/label.rb', line 9 def self.list(api_interface) api_path = 'labels' response = api_interface.send_request(api_path, multipage: true) response.map { |label_entry| label_entry['name'] } end |